==> blesta-3.4.0-3.4.4.zip: blesta/plugins/order/language/en_us/admin_main.php <==
<?php
$lang['AdminMain.!success.status_updated'] = "The selected orders have been successfully updated.";
$lang['AdminMain.!success.settings_updated'] = "Your order settings were successfully updated.";

$lang['AdminMain.index.boxtitle_order'] = "Orders";
$lang['AdminMain.index.no_results'] = "There are no orders of this type.";
$lang['AdminMain.index.category_pending'] = "Pending";
$lang['AdminMain.index.category_accepted'] = "Accepted";
$lang['AdminMain.index.category_fraud'] = "Fraud";
$lang['AdminMain.index.category_canceled'] = "Canceled";

// Order listing
$lang['AdminMain.index.heading_order_number'] = "Order #";
$lang['AdminMain.index.heading_client_id_code'] = "Client ID";
$lang['AdminMain.index.heading_invoice_id_code'] = "Invoice #";
$lang['AdminMain.index.heading_total'] = "Total";
$lang['AdminMain.index.heading_paid'] = "Paid";
$lang['AdminMain.index.heading_date_added'] = "Date Ordered";
$lang['AdminMain.index.field_ordersubmit'] = "Update Orders";
$lang['AdminMain.index.field_markas'] = "Mark as:";

// Order info
$lang['AdminMain.orderinfo.fraudreport_heading'] = "Fraud Report";
$lang['AdminMain.orderinfo.fraudreport_heading_key'] = "Key";
$lang['AdminMain.orderinfo.fraudreport_heading_value'] = "Value";

$lang['AdminMain.orderinfo.applied_heading'] = "Transactions";
$lang['AdminMain.orderinfo.applied_heading_paymenttype'] = "Payment Type";
$lang['AdminMain.orderinfo.applied_heading_amount'] = "Amount";
$lang['AdminMain.orderinfo.applied_heading_applied'] = "Applied";
$lang['AdminMain.orderinfo.applied_heading_appliedon'] = "Applied On";
$lang['AdminMain.orderinfo.applied_heading_options'] = "Options";
$lang['AdminMain.orderinfo.applied_option_edit'] = "Edit";
$lang['AdminMain.orderinfo.applied_no_results'] = "There are no transactions applied to this order.";

$lang['AdminMain.orderinfo.services_heading'] = "Services";
$lang['AdminMain.orderinfo.services_heading_package'] = "Package";
$lang['AdminMain.orderinfo.services_heading_label'] = "Label";
$lang['AdminMain.orderinfo.services_heading_term'] = "Term";
$lang['AdminMain.orderinfo.services_heading_dateadded'] = "Date Added";
$lang['AdminMain.orderinfo.services_heading_daterenews'] = "Date Renews";
$lang['AdminMain.orderinfo.services_heading_options'] = "Options";
$lang['AdminMain.orderinfo.services_option_manage'] = "Manage";

$lang['AdminMain.orderinfo.services_text_never'] = "Never";
$lang['AdminMain.orderinfo.services_no_results'] = "There are no services in this order.";

// Settings
$lang['AdminMain.settings.heading_notifications'] = "Order Notifications";
$lang['AdminMain.settings.field_email_notice'] = "Email";
$lang['AdminMain.settings.field_email_notice_never'] = "Do not send";
$lang['AdminMain.settings.field_email_notice_manual'] = "Only send if manual approval required";
$lang['AdminMain.settings.field_email_notice_always'] = "Always send";
$lang['AdminMain.settings.field_mobile_notice'] = "Mobile";
$lang['AdminMain.settings.field_mobile_notice_never'] = "Do not send";
$lang['AdminMain.settings.field_mobile_notice_manual'] = "Only send if manual approval required";
$lang['AdminMain.settings.field_mobile_notice_always'] = "Always send";

$lang['AdminMain.settings.submit_settings'] = "Update Settings";
$lang['AdminMain.settings.submit_cancel'] = "Return to Order Listing";
?>

==> blesta-4.5.1.zip: blesta/plugins/order/language/en_us/admin_main.php <==
<?php
$lang['AdminMain.!success.status_updated'] = "The selected orders have been successfully updated.";
$lang['AdminMain.!success.settings_updated'] = "Your order settings were successfully updated.";

$lang['AdminMain.index.boxtitle_order'] = "Orders";
$lang['AdminMain.index.no_results'] = "There are no orders of this type.";
$lang['AdminMain.index.category_pending'] = "In Review";
$lang['AdminMain.index.category_accepted'] = "Accepted";
$lang['AdminMain.index.category_fraud'] = "Fraud";
$lang['AdminMain.index.category_canceled'] = "Canceled";

// Order listing
$lang['AdminMain.index.heading_order_number'] = "Order #";
$lang['AdminMain.index.heading_client_id_code'] = "Client ID";
$lang['AdminMain.index.heading_invoice_id_code'] = "Invoice #";
$lang['AdminMain.index.heading_total'] = "Total";
$lang['AdminMain.index.heading_paid'] = "Paid";
$lang['AdminMain.index.heading_date_added'] = "Date Ordered";
$lang['AdminMain.index.field_ordersubmit'] = "Update Orders";
$lang['AdminMain.index.field_markas'] = "Mark as:";
$lang['AdminMain.index.text_location'] = "Location";

// Order info
$lang['AdminMain.orderinfo.fraudreport_heading'] = "Fraud Report";
$lang['AdminMain.orderinfo.fraudreport_heading_key'] = "Key";
$lang['AdminMain.orderinfo.fraudreport_heading_value'] = "Value";

$lang['AdminMain.orderinfo.applied_heading'] = "Transactions";
$lang['AdminMain.orderinfo.applied_heading_paymenttype'] = "Payment Type";
$lang['AdminMain.orderinfo.applied_heading_amount'] = "Amount";
$lang['AdminMain.orderinfo.applied_heading_applied'] = "Applied";
$lang['AdminMain.orderinfo.applied_heading_appliedon'] = "Applied On";
$lang['AdminMain.orderinfo.applied_heading_options'] = "Options";
$lang['AdminMain.orderinfo.applied_option_edit'] = "Edit";
$lang['AdminMain.orderinfo.applied_no_results'] = "There are no transactions applied to this order.";

$lang['AdminMain.orderinfo.services_heading'] = "Services";
$lang['AdminMain.orderinfo.services_heading_package'] = "Package";
$lang['AdminMain.orderinfo.services_heading_label'] = "Label";
$lang['AdminMain.orderinfo.services_heading_term'] = "Term";
$lang['AdminMain.orderinfo.services_heading_dateadded'] = "Date Added";
$lang['AdminMain.orderinfo.services_heading_daterenews'] = "Date Renews";
$lang['AdminMain.orderinfo.services_heading_options'] = "Options";
$lang['AdminMain.orderinfo.services_option_manage'] = "Manage";

$lang['AdminMain.orderinfo.services_text_never'] = "Never";
$lang['AdminMain.orderinfo.services_no_results'] = "There are no services in this order.";

// Settings
$lang['AdminMain.settings.heading_notifications'] = "Order Notifications";
$lang['AdminMain.settings.field_email_notice'] = "Email";
$lang['AdminMain.settings.field_email_notice_never'] = "Do not send";
$lang['AdminMain.settings.field_email_notice_manual'] = "Only send if manual approval required";
$lang['AdminMain.settings.field_email_notice_always'] = "Always send";
$lang['AdminMain.settings.field_mobile_notice'] = "Mobile";
$lang['AdminMain.settings.field_mobile_notice_never'] = "Do not send";
$lang['AdminMain.settings.field_mobile_notice_manual'] = "Only send if manual approval required";
$lang['AdminMain.settings.field_mobile_notice_always'] = "Always send";

$lang['AdminMain.settings.submit_settings'] = "Update Settings";
$lang['AdminMain.settings.submit_cancel'] = "Return to Order Listing";
